// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//  Giuseppe Vacanti (cosine science & computing bv)
//  March 14, 2003
// 
//   $Id: Hkparameter_List.h,v 1.5 2003/08/26 14:46:43 gvacanti Exp $

#ifndef HKPARAMETER_LIST_H
#define HKPARAMETER_LIST_H

#include<Hkparameter_Descriptor.h>

const Hkparameter_Descriptor hkd[] = {

  // MOS1
  {"FILTER_WHEEL_NAME","E1257","TRUE","Name of filter wheel position", Dal::DString, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"FILTER_WHEEL_POSITION","E1317","TRUE","Hardware filter wheel position", Dal::Uint16, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  //  {"FILTER_RAW","E1317","TRUE","", Dal::Uint16, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"CLOCK_RESET_TIME_COARSE","E1573","TRUE","Coarse component of the clock reset time", Dal::Int32, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"CLOCK_RESET_TIME_FINE","EU573","TRUE","Fine component of the clock reset time", Dal::Uint16, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"CLOCK_WRAP_AROUND","E1044","TRUE","Clock wrap around", Dal::Uint16, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"GAIN_CCD_1_RAW","E1113","TRUE","Gain of the read out chain", Dal::DString, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"GAIN_CCD_2_RAW","E1201","TRUE","Gain of the read out chain", Dal::DString, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"GAIN_CCD_3_RAW","E1302","TRUE","Gain of the read out chain", Dal::DString, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"GAIN_CCD_4_RAW","E1248","TRUE","Gain of the read out chain", Dal::DString, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"GAIN_CCD_5_RAW","E1201","TRUE","Gain of the read out chain", Dal::DString, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"GAIN_CCD_6_RAW","E1302","TRUE","Gain of the read out chain", Dal::DString, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"GAIN_CCD_7_RAW","E1248","TRUE","Gain of the read out chain", Dal::DString, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"MEAN_TEMPERATURE", "E1311", "TRUE", "Temperature", Dal::Real32,  Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_0_LOW_THR_1","E1398","TRUE","First low threshold of 1st EDU", Dal::Uint16, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_0_LOW_THR_2","E1399","TRUE","Second low threshold of 1st EDU", Dal::Uint16, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_1_LOW_THR_1","E1400","TRUE","First low threshold of 2nd EDU", Dal::Uint16, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_1_LOW_THR_2","E1401","TRUE","Second low threshold of 2nd EDU", Dal::Uint16, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_2_LOW_THR_1","E1402","TRUE","First low threshold of 3rd EDU", Dal::Uint16, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_2_LOW_THR_2","E1403","TRUE","Second low threshold of 3rd EDU", Dal::Uint16, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_3_LOW_THR_1","E1404","TRUE","First low threshold of 4th EDU", Dal::Uint16, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_3_LOW_THR_2","E1405","TRUE","Second low threshold of 4th EDU", Dal::Uint16, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_4_LOW_THR_1","E1406","TRUE","First low threshold of 5th EDU", Dal::Uint16, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_4_LOW_THR_2","E1407","TRUE","Second low threshold of 5th EDU", Dal::Uint16, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_5_LOW_THR_1","E1408","TRUE","First low threshold of 6th EDU", Dal::Uint16, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_5_LOW_THR_2","E1409","TRUE","Second low threshold of 6th EDU", Dal::Uint16, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_6_LOW_THR_1","E1410","TRUE","First low threshold of 7th EDU", Dal::Uint16, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_6_LOW_THR_2","E1411","TRUE","Second low threshold of 7th EDU", Dal::Uint16, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_7_LOW_THR_1","E1412","TRUE","First low threshold of 8th EDU", Dal::Uint16, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_7_LOW_THR_2","E1413","TRUE","Second low threshold of 8th EDU", Dal::Uint16, Xmm::EMOS1, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"HBR_0_ACTIVATION_STATUS","HBRACTIV","HBRID == 1","Activation status for HBR 0", Dal::Int8, Xmm::EMOS1,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_0_PROCESSING_MODE","HBRPROC","HBRID == 1","Processing mode for HBR 0", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_1_ACTIVATION_STATUS","HBRACTIV","HBRID == 2","Activation status for HBR 1", Dal::Int8, Xmm::EMOS1,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_1_PROCESSING_MODE","HBRPROC","HBRID == 2","Processing mode for HBR 1", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_2_ACTIVATION_STATUS","HBRACTIV","HBRID == 3","Activation status for HBR 2", Dal::Int8, Xmm::EMOS1,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_2_PROCESSING_MODE","HBRPROC","HBRID == 3","Processing mode for HBR 2", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_3_ACTIVATION_STATUS","HBRACTIV","HBRID == 4","Activation status for HBR 3", Dal::Int8, Xmm::EMOS1,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_3_PROCESSING_MODE","HBRPROC","HBRID == 4","Processing mode for HBR 3", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_4_ACTIVATION_STATUS","HBRACTIV","HBRID == 5","Activation status for HBR 4", Dal::Int8, Xmm::EMOS1,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_4_PROCESSING_MODE","HBRPROC","HBRID == 5","Processing mode for HBR 4", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_5_ACTIVATION_STATUS","HBRACTIV","HBRID == 6","Activation status for HBR 5", Dal::Int8, Xmm::EMOS1,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_5_PROCESSING_MODE","HBRPROC","HBRID == 6","Processing mode for HBR 5", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_6_ACTIVATION_STATUS","HBRACTIV","HBRID == 7","Activation status for HBR 6", Dal::Int8, Xmm::EMOS1,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_6_PROCESSING_MODE","HBRPROC","HBRID == 7","Processing mode for HBR 6", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_7_ACTIVATION_STATUS","HBRACTIV","HBRID == 8","Activation status for HBR 7", Dal::Int8, Xmm::EMOS1,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_7_PROCESSING_MODE","HBRPROC","HBRID == 8","Processing mode for HBR 7", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_PATTERN_REFERENCE_0","PATTERN","HBRID == 1","Pattern reference for HBR 0", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_LOW_THR_0","LTHRESH","HBRID == 1","Low threshold for HBR 0", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_HIG_THR_0","UTHRESH","HBRID == 1","High threshold for HBR 0", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_PATTERN_REFERENCE_1","PATTERN","HBRID == 2","Pattern reference for HBR 1", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_LOW_THR_1","LTHRESH","HBRID == 2","Low threshold for HBR 1", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_HIG_THR_1","UTHRESH","HBRID == 2","High threshold for HBR 1", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_PATTERN_REFERENCE_2","PATTERN","HBRID == 3","Pattern reference for HBR 2", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_LOW_THR_2","LTHRESH","HBRID == 3","Low threshold for HBR 2", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_HIG_THR_2","UTHRESH","HBRID == 3","High threshold for HBR 2", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_PATTERN_REFERENCE_3","PATTERN","HBRID == 4","Pattern reference for HBR 3", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_LOW_THR_3","LTHRESH","HBRID == 4","Low threshold for HBR 3", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_HIG_THR_3","UTHRESH","HBRID == 4","High threshold for HBR 3", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_PATTERN_REFERENCE_4","PATTERN","HBRID == 5","Pattern reference for HBR 4", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_LOW_THR_4","LTHRESH","HBRID == 5","Low threshold for HBR 4", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_HIG_THR_4","UTHRESH","HBRID == 5","High threshold for HBR 4", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_PATTERN_REFERENCE_5","PATTERN","HBRID == 6","Pattern reference for HBR 5", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_LOW_THR_5","LTHRESH","HBRID == 6","Low threshold for HBR 5", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_HIG_THR_5","UTHRESH","HBRID == 6","High threshold for HBR 5", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_PATTERN_REFERENCE_6","PATTERN","HBRID == 7","Pattern reference for HBR 6", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_LOW_THR_6","LTHRESH","HBRID == 7","Low threshold for HBR 6", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_HIG_THR_6","UTHRESH","HBRID == 7","High threshold for HBR 6", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_PATTERN_REFERENCE_7","PATTERN","HBRID == 8","Pattern reference for HBR 7", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_LOW_THR_7","LTHRESH","HBRID == 8","Low threshold for HBR 7", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_HIG_THR_7","UTHRESH","HBRID == 8","High threshold for HBR 7", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},

  // MOS2
  {"FILTER_WHEEL_NAME","K1257","TRUE","Name of filter wheel position", Dal::DString, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"FILTER_WHEEL_POSITION","K1317","TRUE","Hardware filter wheel position", Dal::Uint16, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  //  {"FILTER_RAW","K1317","TRUE","Filter", Dal::Uint16, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"CLOCK_RESET_TIME_COARSE","K1573","TRUE","Coarse component of the clock reset time", Dal::Int32, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"CLOCK_RESET_TIME_FINE","KU573","TRUE","Fine component of the clock reset time", Dal::Uint16, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"CLOCK_WRAP_AROUND","K1044","TRUE","Clock wrap around", Dal::Uint16, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"GAIN_CCD_1_RAW","K1113","TRUE","Gain of the read out chain", Dal::DString, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"GAIN_CCD_2_RAW","K1201","TRUE","Gain of the read out chain", Dal::DString, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"GAIN_CCD_3_RAW","K1302","TRUE","Gain of the read out chain", Dal::DString, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"GAIN_CCD_4_RAW","K1248","TRUE","Gain of the read out chain", Dal::DString, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"GAIN_CCD_5_RAW","K1201","TRUE","Gain of the read out chain", Dal::DString, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"GAIN_CCD_6_RAW","K1302","TRUE","Gain of the read out chain", Dal::DString, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"GAIN_CCD_7_RAW","K1248","TRUE","Gain of the read out chain", Dal::DString, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"MEAN_TEMPERATURE", "K1311", "TRUE", "Temperature", Dal::Real32,  Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_0_LOW_THR_1","K1398","TRUE","First low threshold of 1st EDU", Dal::Uint16, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_0_LOW_THR_2","K1399","TRUE","Second low threshold of 1st EDU", Dal::Uint16, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_1_LOW_THR_1","K1400","TRUE","First low threshold of 2nd EDU", Dal::Uint16, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_1_LOW_THR_2","K1401","TRUE","Second low threshold of 2nd EDU", Dal::Uint16, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_2_LOW_THR_1","K1402","TRUE","First low threshold of 3rd EDU", Dal::Uint16, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_2_LOW_THR_2","K1403","TRUE","Second low threshold of 3rd EDU", Dal::Uint16, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_3_LOW_THR_1","K1404","TRUE","First low threshold of 4th EDU", Dal::Uint16, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_3_LOW_THR_2","K1405","TRUE","Second low threshold of 4th EDU", Dal::Uint16, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_4_LOW_THR_1","K1406","TRUE","First low threshold of 5th EDU", Dal::Uint16, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_4_LOW_THR_2","K1407","TRUE","Second low threshold of 5th EDU", Dal::Uint16, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_5_LOW_THR_1","K1408","TRUE","First low threshold of 6th EDU", Dal::Uint16, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_5_LOW_THR_2","K1409","TRUE","Second low threshold of 6th EDU", Dal::Uint16, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_6_LOW_THR_1","K1410","TRUE","First low threshold of 7th EDU", Dal::Uint16, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_6_LOW_THR_2","K1411","TRUE","Second low threshold of 7th EDU", Dal::Uint16, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_7_LOW_THR_1","K1412","TRUE","First low threshold of 8th EDU", Dal::Uint16, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"EDU_7_LOW_THR_2","K1413","TRUE","Second low threshold of 8th EDU", Dal::Uint16, Xmm::EMOS2, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"HBR_0_ACTIVATION_STATUS","HBRACTIV","HBRID == 1","Activation status for HBR 0", Dal::Int8, Xmm::EMOS2,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_0_PROCESSING_MODE","HBRPROC","HBRID == 1","Processing mode for HBR 0", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_1_ACTIVATION_STATUS","HBRACTIV","HBRID == 2","Activation status for HBR 1", Dal::Int8, Xmm::EMOS2,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_1_PROCESSING_MODE","HBRPROC","HBRID == 2","Processing mode for HBR 1", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_2_ACTIVATION_STATUS","HBRACTIV","HBRID == 3","Activation status for HBR 2", Dal::Int8, Xmm::EMOS2,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_2_PROCESSING_MODE","HBRPROC","HBRID == 3","Processing mode for HBR 2", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_3_ACTIVATION_STATUS","HBRACTIV","HBRID == 4","Activation status for HBR 3", Dal::Int8, Xmm::EMOS2,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_3_PROCESSING_MODE","HBRPROC","HBRID == 4","Processing mode for HBR 3", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_4_ACTIVATION_STATUS","HBRACTIV","HBRID == 5","Activation status for HBR 4", Dal::Int8, Xmm::EMOS2,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_4_PROCESSING_MODE","HBRPROC","HBRID == 5","Processing mode for HBR 4", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_5_ACTIVATION_STATUS","HBRACTIV","HBRID == 6","Activation status for HBR 5", Dal::Int8, Xmm::EMOS2,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_5_PROCESSING_MODE","HBRPROC","HBRID == 6","Processing mode for HBR 5", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_6_ACTIVATION_STATUS","HBRACTIV","HBRID == 7","Activation status for HBR 6", Dal::Int8, Xmm::EMOS2,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_6_PROCESSING_MODE","HBRPROC","HBRID == 7","Processing mode for HBR 6", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_7_ACTIVATION_STATUS","HBRACTIV","HBRID == 8","Activation status for HBR 7", Dal::Int8, Xmm::EMOS2,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_7_PROCESSING_MODE","HBRPROC","HBRID == 8","Processing mode for HBR 7", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_PATTERN_REFERENCE_0","PATTERN","HBRID == 1","Pattern reference for HBR 0", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_LOW_THR_0","LTHRESH","HBRID == 1","Low threshold for HBR 0", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_HIG_THR_0","UTHRESH","HBRID == 1","High threshold for HBR 0", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_PATTERN_REFERENCE_1","PATTERN","HBRID == 2","Pattern reference for HBR 1", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_LOW_THR_1","LTHRESH","HBRID == 2","Low threshold for HBR 1", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_HIG_THR_1","UTHRESH","HBRID == 2","High threshold for HBR 1", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_PATTERN_REFERENCE_2","PATTERN","HBRID == 3","Pattern reference for HBR 2", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_LOW_THR_2","LTHRESH","HBRID == 3","Low threshold for HBR 2", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_HIG_THR_2","UTHRESH","HBRID == 3","High threshold for HBR 2", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_PATTERN_REFERENCE_3","PATTERN","HBRID == 4","Pattern reference for HBR 3", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_LOW_THR_3","LTHRESH","HBRID == 4","Low threshold for HBR 3", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_HIG_THR_3","UTHRESH","HBRID == 4","High threshold for HBR 3", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_PATTERN_REFERENCE_4","PATTERN","HBRID == 5","Pattern reference for HBR 4", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_LOW_THR_4","LTHRESH","HBRID == 5","Low threshold for HBR 4", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_HIG_THR_4","UTHRESH","HBRID == 5","High threshold for HBR 4", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_PATTERN_REFERENCE_5","PATTERN","HBRID == 6","Pattern reference for HBR 5", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_LOW_THR_5","LTHRESH","HBRID == 6","Low threshold for HBR 5", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_HIG_THR_5","UTHRESH","HBRID == 6","High threshold for HBR 5", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_PATTERN_REFERENCE_6","PATTERN","HBRID == 7","Pattern reference for HBR 6", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_LOW_THR_6","LTHRESH","HBRID == 7","Low threshold for HBR 6", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_HIG_THR_6","UTHRESH","HBRID == 7","High threshold for HBR 6", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_PATTERN_REFERENCE_7","PATTERN","HBRID == 8","Pattern reference for HBR 7", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_LOW_THR_7","LTHRESH","HBRID == 8","Low threshold for HBR 7", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},
  {"HBR_HIG_THR_7","UTHRESH","HBRID == 8","High threshold for HBR 7", Dal::Uint16, Xmm::EMOS2,Xmm::HBR_THRESHOLD_HOUSEKEEPING, false},

  // RGS1
  {"PACKING_SCHEME","G7303","TRUE","Packing scheme", Dal::DString, Xmm::RGS1, Xmm::FULL_PERIODIC_HOUSEKEEPING, true},
  {"CCD_1_ACCEPT_THR_C","ATHRESHC","CCDID == 1","Acceptance threshold side C for CCD 1", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_1_ACCEPT_THR_D","ATHRESHD","CCDID == 1","Acceptance threshold side D for CCD 1", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_1_UPPER_THR_C","UTHRESHC","CCDID == 1","Upper threshold side C for CCD 1", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_1_UPPER_THR_D","UTHRESHD","CCDID == 1","Acceptance threshold side D for CCD 1", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_2_ACCEPT_THR_C","ATHRESHC","CCDID == 2","Acceptance threshold side C for CCD 2", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_2_ACCEPT_THR_D","ATHRESHD","CCDID == 2","Acceptance threshold side D for CCD 2", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_2_UPPER_THR_C","UTHRESHC","CCDID == 2","Upper threshold side C for CCD 2", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_2_UPPER_THR_D","UTHRESHD","CCDID == 2","Acceptance threshold side D for CCD 2", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_3_ACCEPT_THR_C","ATHRESHC","CCDID == 3","Acceptance threshold side C for CCD 3", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_3_ACCEPT_THR_D","ATHRESHD","CCDID == 3","Acceptance threshold side D for CCD 3", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_3_UPPER_THR_C","UTHRESHC","CCDID == 3","Upper threshold side C for CCD 3", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_3_UPPER_THR_D","UTHRESHD","CCDID == 3","Acceptance threshold side D for CCD 3", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_4_ACCEPT_THR_C","ATHRESHC","CCDID == 4","Acceptance threshold side C for CCD 4", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_4_ACCEPT_THR_D","ATHRESHD","CCDID == 4","Acceptance threshold side D for CCD 4", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_4_UPPER_THR_C","UTHRESHC","CCDID == 4","Upper threshold side C for CCD 4", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_4_UPPER_THR_D","UTHRESHD","CCDID == 4","Acceptance threshold side D for CCD 4", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_5_ACCEPT_THR_C","ATHRESHC","CCDID == 5","Acceptance threshold side C for CCD 5", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_5_ACCEPT_THR_D","ATHRESHD","CCDID == 5","Acceptance threshold side D for CCD 5", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_5_UPPER_THR_C","UTHRESHC","CCDID == 5","Upper threshold side C for CCD 5", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_5_UPPER_THR_D","UTHRESHD","CCDID == 5","Acceptance threshold side D for CCD 5", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_6_ACCEPT_THR_C","ATHRESHC","CCDID == 6","Acceptance threshold side C for CCD 6", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_6_ACCEPT_THR_D","ATHRESHD","CCDID == 6","Acceptance threshold side D for CCD 6", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_6_UPPER_THR_C","UTHRESHC","CCDID == 6","Upper threshold side C for CCD 6", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_6_UPPER_THR_D","UTHRESHD","CCDID == 6","Acceptance threshold side D for CCD 6", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_7_ACCEPT_THR_C","ATHRESHC","CCDID == 7","Acceptance threshold side C for CCD 7", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_7_ACCEPT_THR_D","ATHRESHD","CCDID == 7","Acceptance threshold side D for CCD 7", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_7_UPPER_THR_C","UTHRESHC","CCDID == 7","Upper threshold side C for CCD 7", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_7_UPPER_THR_D","UTHRESHD","CCDID == 7","Acceptance threshold side D for CCD 7", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_8_ACCEPT_THR_C","ATHRESHC","CCDID == 8","Acceptance threshold side C for CCD 8", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_8_ACCEPT_THR_D","ATHRESHD","CCDID == 8","Acceptance threshold side D for CCD 8", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_8_UPPER_THR_C","UTHRESHC","CCDID == 8","Upper threshold side C for CCD 8", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_8_UPPER_THR_D","UTHRESHD","CCDID == 8","Acceptance threshold side D for CCD 8", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_9_ACCEPT_THR_C","ATHRESHC","CCDID == 9","Acceptance threshold side C for CCD 9", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_9_ACCEPT_THR_D","ATHRESHD","CCDID == 9","Acceptance threshold side D for CCD 9", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_9_UPPER_THR_C","UTHRESHC","CCDID == 9","Upper threshold side C for CCD 9", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_9_UPPER_THR_D","UTHRESHD","CCDID == 9","Acceptance threshold side D for CCD 9", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1, false},
  {"NUMBER_OF_SLOTS","CCDSNUM","TRUE","Number of readout slots", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_1","RDOUTSEQ","#ROW == 1","CCD read out in the 1st slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_1_OCB","OCBMODE","#ROW == 1","On-chip binning factor for the CCD read out in the 1st slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_1_NODES","READOUT","#ROW == 1","Read-out nodes used fot the CCD read out in the 1st slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_1_REJECT_THR_C","REJTHRC","#ROW == 1","Rejection threshold side C for the CCD read out in the 1st slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_1_REJECT_THR_D","REJTHRD","#ROW == 1","Rejection threshold side D for the CCD read out in the 1st slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_1_CSG_PATTERN","CSGPATT","#ROW == 1","CCD read out in the 1st slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_2","RDOUTSEQ","#ROW == 2","CCD read out in the 2nd slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_2_OCB","OCBMODE","#ROW == 2","On-chip binning factor for the CCD read out in the 2nd slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_2_NODES","READOUT","#ROW == 2","Read-out nodes used fot the CCD read out in the 2nd slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_2_REJECT_THR_C","REJTHRC","#ROW == 2","Rejection threshold side C for the CCD read out in the 2nd slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_2_REJECT_THR_D","REJTHRD","#ROW == 2","Rejection threshold side D for the CCD read out in the 2nd slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_2_CSG_PATTERN","CSGPATT","#ROW == 2","CCD read out in the 2nd slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_3","RDOUTSEQ","#ROW == 3","CCD read out in the 3rd slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_3_OCB","OCBMODE","#ROW == 3","On-chip binning factor for the CCD read out in the 3rd slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_3_NODES","READOUT","#ROW == 3","Read-out nodes used fot the CCD read out in the 3rd slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_3_REJECT_THR_C","REJTHRC","#ROW == 3","Rejection threshold side C for the CCD read out in the 3rd slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_3_REJECT_THR_D","REJTHRD","#ROW == 3","Rejection threshold side D for the CCD read out in the 3rd slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_3_CSG_PATTERN","CSGPATT","#ROW == 3","CCD read out in the 3rd slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_4","RDOUTSEQ","#ROW == 4","CCD read out in the 4th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_4_OCB","OCBMODE","#ROW == 4","On-chip binning factor for the CCD read out in the 4th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_4_NODES","READOUT","#ROW == 4","Read-out nodes used fot the CCD read out in the 4th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_4_REJECT_THR_C","REJTHRC","#ROW == 4","Rejection threshold side C for the CCD read out in the 4th slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_4_REJECT_THR_D","REJTHRD","#ROW == 4","Rejection threshold side D for the CCD read out in the 4th slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_4_CSG_PATTERN","CSGPATT","#ROW == 4","CCD read out in the 4th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_5","RDOUTSEQ","#ROW == 5","CCD read out in the 5th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_5_OCB","OCBMODE","#ROW == 5","On-chip binning factor for the CCD read out in the 5th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_5_NODES","READOUT","#ROW == 5","Read-out nodes used fot the CCD read out in the 5th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_5_REJECT_THR_C","REJTHRC","#ROW == 5","Rejection threshold side C for the CCD read out in the 5th slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_5_REJECT_THR_D","REJTHRD","#ROW == 5","Rejection threshold side D for the CCD read out in the 5th slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_5_CSG_PATTERN","CSGPATT","#ROW == 5","CCD read out in the 5th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_6","RDOUTSEQ","#ROW == 6","CCD read out in the 6th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_6_OCB","OCBMODE","#ROW == 6","On-chip binning factor for the CCD read out in the 6th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_6_NODES","READOUT","#ROW == 6","Read-out nodes used fot the CCD read out in the 6th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_6_REJECT_THR_C","REJTHRC","#ROW == 6","Rejection threshold side C for the CCD read out in the 6th slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_6_REJECT_THR_D","REJTHRD","#ROW == 6","Rejection threshold side D for the CCD read out in the 6th slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_6_CSG_PATTERN","CSGPATT","#ROW == 6","CCD read out in the 6th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_7","RDOUTSEQ","#ROW == 7","CCD read out in the 7th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_7_OCB","OCBMODE","#ROW == 7","On-chip binning factor for the CCD read out in the 7th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_7_NODES","READOUT","#ROW == 7","Read-out nodes used fot the CCD read out in the 7th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_7_REJECT_THR_C","REJTHRC","#ROW == 7","Rejection threshold side C for the CCD read out in the 7th slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_7_REJECT_THR_D","REJTHRD","#ROW == 7","Rejection threshold side D for the CCD read out in the 7th slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_7_CSG_PATTERN","CSGPATT","#ROW == 7","CCD read out in the 7th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_8","RDOUTSEQ","#ROW == 8","CCD read out in the 8th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_8_OCB","OCBMODE","#ROW == 8","On-chip binning factor for the CCD read out in the 8th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_8_NODES","READOUT","#ROW == 8","Read-out nodes used fot the CCD read out in the 8th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_8_REJECT_THR_C","REJTHRC","#ROW == 8","Rejection threshold side C for the CCD read out in the 8th slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_8_REJECT_THR_D","REJTHRD","#ROW == 8","Rejection threshold side D for the CCD read out in the 8th slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_8_CSG_PATTERN","CSGPATT","#ROW == 8","CCD read out in the 8th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_9","RDOUTSEQ","#ROW == 9","CCD read out in the 9th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_9_OCB","OCBMODE","#ROW == 9","On-chip binning factor for the CCD read out in the 9th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_9_NODES","READOUT","#ROW == 9","Read-out nodes used fot the CCD read out in the 9th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_9_REJECT_THR_C","REJTHRC","#ROW == 9","Rejection threshold side C for the CCD read out in the 9th slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_9_REJECT_THR_D","REJTHRD","#ROW == 9","Rejection threshold side D for the CCD read out in the 9th slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_9_CSG_PATTERN","CSGPATT","#ROW == 9","CCD read out in the 9th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_10","RDOUTSEQ","#ROW == 10","CCD read out in the 10th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_10_OCB","OCBMODE","#ROW == 10","On-chip binning factor for the CCD read out in the 10th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_10_NODES","READOUT","#ROW == 10","Read-out nodes used fot the CCD read out in the 10th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_10_REJECT_THR_C","REJTHRC","#ROW == 10","Rejection threshold side C for the CCD read out in the 10th slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_10_REJECT_THR_D","REJTHRD","#ROW == 10","Rejection threshold side D for the CCD read out in the 10th slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_10_CSG_PATTERN","CSGPATT","#ROW == 10","CCD read out in the 10th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_11","RDOUTSEQ","#ROW == 11","CCD read out in the 11th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_11_OCB","OCBMODE","#ROW == 11","On-chip binning factor for the CCD read out in the 11th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_11_NODES","READOUT","#ROW == 11","Read-out nodes used fot the CCD read out in the 11th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_11_REJECT_THR_C","REJTHRC","#ROW == 11","Rejection threshold side C for the CCD read out in the 11th slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_11_REJECT_THR_D","REJTHRD","#ROW == 11","Rejection threshold side D for the CCD read out in the 11th slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_11_CSG_PATTERN","CSGPATT","#ROW == 11","CCD read out in the 11th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_12","RDOUTSEQ","#ROW == 12","CCD read out in the 12th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_12_OCB","OCBMODE","#ROW == 12","On-chip binning factor for the CCD read out in the 12th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_12_NODES","READOUT","#ROW == 12","Read-out nodes used fot the CCD read out in the 12th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_12_REJECT_THR_C","REJTHRC","#ROW == 12","Rejection threshold side C for the CCD read out in the 12th slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_12_REJECT_THR_D","REJTHRD","#ROW == 12","Rejection threshold side D for the CCD read out in the 12th slot", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_12_CSG_PATTERN","CSGPATT","#ROW == 12","CCD read out in the 12th slot", Dal::Int8, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false},

  // RGS2
  {"PACKING_SCHEME","L7303","TRUE","Packing scheme", Dal::DString, Xmm::RGS2, Xmm::FULL_PERIODIC_HOUSEKEEPING, true},
  {"CCD_1_ACCEPT_THR_C","ATHRESHC","CCDID == 1","Acceptance threshold side C for CCD 1", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_1_ACCEPT_THR_D","ATHRESHD","CCDID == 1","Acceptance threshold side D for CCD 1", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_1_UPPER_THR_C","UTHRESHC","CCDID == 1","Upper threshold side C for CCD 1", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_1_UPPER_THR_D","UTHRESHD","CCDID == 1","Acceptance threshold side D for CCD 1", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_2_ACCEPT_THR_C","ATHRESHC","CCDID == 2","Acceptance threshold side C for CCD 2", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_2_ACCEPT_THR_D","ATHRESHD","CCDID == 2","Acceptance threshold side D for CCD 2", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_2_UPPER_THR_C","UTHRESHC","CCDID == 2","Upper threshold side C for CCD 2", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_2_UPPER_THR_D","UTHRESHD","CCDID == 2","Acceptance threshold side D for CCD 2", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_3_ACCEPT_THR_C","ATHRESHC","CCDID == 3","Acceptance threshold side C for CCD 3", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_3_ACCEPT_THR_D","ATHRESHD","CCDID == 3","Acceptance threshold side D for CCD 3", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_3_UPPER_THR_C","UTHRESHC","CCDID == 3","Upper threshold side C for CCD 3", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_3_UPPER_THR_D","UTHRESHD","CCDID == 3","Acceptance threshold side D for CCD 3", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_4_ACCEPT_THR_C","ATHRESHC","CCDID == 4","Acceptance threshold side C for CCD 4", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_4_ACCEPT_THR_D","ATHRESHD","CCDID == 4","Acceptance threshold side D for CCD 4", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_4_UPPER_THR_C","UTHRESHC","CCDID == 4","Upper threshold side C for CCD 4", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_4_UPPER_THR_D","UTHRESHD","CCDID == 4","Acceptance threshold side D for CCD 4", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_5_ACCEPT_THR_C","ATHRESHC","CCDID == 5","Acceptance threshold side C for CCD 5", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_5_ACCEPT_THR_D","ATHRESHD","CCDID == 5","Acceptance threshold side D for CCD 5", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_5_UPPER_THR_C","UTHRESHC","CCDID == 5","Upper threshold side C for CCD 5", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_5_UPPER_THR_D","UTHRESHD","CCDID == 5","Acceptance threshold side D for CCD 5", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_6_ACCEPT_THR_C","ATHRESHC","CCDID == 6","Acceptance threshold side C for CCD 6", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_6_ACCEPT_THR_D","ATHRESHD","CCDID == 6","Acceptance threshold side D for CCD 6", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_6_UPPER_THR_C","UTHRESHC","CCDID == 6","Upper threshold side C for CCD 6", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_6_UPPER_THR_D","UTHRESHD","CCDID == 6","Acceptance threshold side D for CCD 6", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_7_ACCEPT_THR_C","ATHRESHC","CCDID == 7","Acceptance threshold side C for CCD 7", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_7_ACCEPT_THR_D","ATHRESHD","CCDID == 7","Acceptance threshold side D for CCD 7", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_7_UPPER_THR_C","UTHRESHC","CCDID == 7","Upper threshold side C for CCD 7", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_7_UPPER_THR_D","UTHRESHD","CCDID == 7","Acceptance threshold side D for CCD 7", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_8_ACCEPT_THR_C","ATHRESHC","CCDID == 8","Acceptance threshold side C for CCD 8", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_8_ACCEPT_THR_D","ATHRESHD","CCDID == 8","Acceptance threshold side D for CCD 8", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_8_UPPER_THR_C","UTHRESHC","CCDID == 8","Upper threshold side C for CCD 8", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_8_UPPER_THR_D","UTHRESHD","CCDID == 8","Acceptance threshold side D for CCD 8", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_9_ACCEPT_THR_C","ATHRESHC","CCDID == 9","Acceptance threshold side C for CCD 9", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_9_ACCEPT_THR_D","ATHRESHD","CCDID == 9","Acceptance threshold side D for CCD 9", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_9_UPPER_THR_C","UTHRESHC","CCDID == 9","Upper threshold side C for CCD 9", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"CCD_9_UPPER_THR_D","UTHRESHD","CCDID == 9","Acceptance threshold side D for CCD 9", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_1, false},
  {"NUMBER_OF_SLOTS","CCDSNUM","TRUE","Number of readout slots", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_1","RDOUTSEQ","#ROW == 1","CCD read out in the 1st slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_1_OCB","OCBMODE","#ROW == 1","On-chip binning factor for the CCD read out in the 1st slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_1_NODES","READOUT","#ROW == 1","Read-out nodes used fot the CCD read out in the 1st slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_1_REJECT_THR_C","REJTHRC","#ROW == 1","Rejection threshold side C for the CCD read out in the 1st slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_1_REJECT_THR_D","REJTHRD","#ROW == 1","Rejection threshold side D for the CCD read out in the 1st slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_1_CSG_PATTERN","CSGPATT","#ROW == 1","CCD read out in the 1st slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_2","RDOUTSEQ","#ROW == 2","CCD read out in the 2nd slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_2_OCB","OCBMODE","#ROW == 2","On-chip binning factor for the CCD read out in the 2nd slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_2_NODES","READOUT","#ROW == 2","Read-out nodes used fot the CCD read out in the 2nd slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_2_REJECT_THR_C","REJTHRC","#ROW == 2","Rejection threshold side C for the CCD read out in the 2nd slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_2_REJECT_THR_D","REJTHRD","#ROW == 2","Rejection threshold side D for the CCD read out in the 2nd slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_2_CSG_PATTERN","CSGPATT","#ROW == 2","CCD read out in the 2nd slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_3","RDOUTSEQ","#ROW == 3","CCD read out in the 3rd slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_3_OCB","OCBMODE","#ROW == 3","On-chip binning factor for the CCD read out in the 3rd slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_3_NODES","READOUT","#ROW == 3","Read-out nodes used fot the CCD read out in the 3rd slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_3_REJECT_THR_C","REJTHRC","#ROW == 3","Rejection threshold side C for the CCD read out in the 3rd slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_3_REJECT_THR_D","REJTHRD","#ROW == 3","Rejection threshold side D for the CCD read out in the 3rd slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_3_CSG_PATTERN","CSGPATT","#ROW == 3","CCD read out in the 3rd slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_4","RDOUTSEQ","#ROW == 4","CCD read out in the 4th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_4_OCB","OCBMODE","#ROW == 4","On-chip binning factor for the CCD read out in the 4th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_4_NODES","READOUT","#ROW == 4","Read-out nodes used fot the CCD read out in the 4th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_4_REJECT_THR_C","REJTHRC","#ROW == 4","Rejection threshold side C for the CCD read out in the 4th slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_4_REJECT_THR_D","REJTHRD","#ROW == 4","Rejection threshold side D for the CCD read out in the 4th slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_4_CSG_PATTERN","CSGPATT","#ROW == 4","CCD read out in the 4th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_5","RDOUTSEQ","#ROW == 5","CCD read out in the 5th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_5_OCB","OCBMODE","#ROW == 5","On-chip binning factor for the CCD read out in the 5th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_5_NODES","READOUT","#ROW == 5","Read-out nodes used fot the CCD read out in the 5th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_5_REJECT_THR_C","REJTHRC","#ROW == 5","Rejection threshold side C for the CCD read out in the 5th slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_5_REJECT_THR_D","REJTHRD","#ROW == 5","Rejection threshold side D for the CCD read out in the 5th slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_5_CSG_PATTERN","CSGPATT","#ROW == 5","CCD read out in the 5th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_6","RDOUTSEQ","#ROW == 6","CCD read out in the 6th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_6_OCB","OCBMODE","#ROW == 6","On-chip binning factor for the CCD read out in the 6th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_6_NODES","READOUT","#ROW == 6","Read-out nodes used fot the CCD read out in the 6th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_6_REJECT_THR_C","REJTHRC","#ROW == 6","Rejection threshold side C for the CCD read out in the 6th slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_6_REJECT_THR_D","REJTHRD","#ROW == 6","Rejection threshold side D for the CCD read out in the 6th slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_6_CSG_PATTERN","CSGPATT","#ROW == 6","CCD read out in the 6th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_7","RDOUTSEQ","#ROW == 7","CCD read out in the 7th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_7_OCB","OCBMODE","#ROW == 7","On-chip binning factor for the CCD read out in the 7th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_7_NODES","READOUT","#ROW == 7","Read-out nodes used fot the CCD read out in the 7th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_7_REJECT_THR_C","REJTHRC","#ROW == 7","Rejection threshold side C for the CCD read out in the 7th slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_7_REJECT_THR_D","REJTHRD","#ROW == 7","Rejection threshold side D for the CCD read out in the 7th slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_7_CSG_PATTERN","CSGPATT","#ROW == 7","CCD read out in the 7th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_8","RDOUTSEQ","#ROW == 8","CCD read out in the 8th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_8_OCB","OCBMODE","#ROW == 8","On-chip binning factor for the CCD read out in the 8th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_8_NODES","READOUT","#ROW == 8","Read-out nodes used fot the CCD read out in the 8th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_8_REJECT_THR_C","REJTHRC","#ROW == 8","Rejection threshold side C for the CCD read out in the 8th slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_8_REJECT_THR_D","REJTHRD","#ROW == 8","Rejection threshold side D for the CCD read out in the 8th slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_8_CSG_PATTERN","CSGPATT","#ROW == 8","CCD read out in the 8th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_9","RDOUTSEQ","#ROW == 9","CCD read out in the 9th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_9_OCB","OCBMODE","#ROW == 9","On-chip binning factor for the CCD read out in the 9th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_9_NODES","READOUT","#ROW == 9","Read-out nodes used fot the CCD read out in the 9th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_9_REJECT_THR_C","REJTHRC","#ROW == 9","Rejection threshold side C for the CCD read out in the 9th slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_9_REJECT_THR_D","REJTHRD","#ROW == 9","Rejection threshold side D for the CCD read out in the 9th slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_9_CSG_PATTERN","CSGPATT","#ROW == 9","CCD read out in the 9th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_10","RDOUTSEQ","#ROW == 10","CCD read out in the 10th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_10_OCB","OCBMODE","#ROW == 10","On-chip binning factor for the CCD read out in the 10th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_10_NODES","READOUT","#ROW == 10","Read-out nodes used fot the CCD read out in the 10th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_10_REJECT_THR_C","REJTHRC","#ROW == 10","Rejection threshold side C for the CCD read out in the 10th slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_10_REJECT_THR_D","REJTHRD","#ROW == 10","Rejection threshold side D for the CCD read out in the 10th slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_10_CSG_PATTERN","CSGPATT","#ROW == 10","CCD read out in the 10th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_11","RDOUTSEQ","#ROW == 11","CCD read out in the 11th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_11_OCB","OCBMODE","#ROW == 11","On-chip binning factor for the CCD read out in the 11th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_11_NODES","READOUT","#ROW == 11","Read-out nodes used fot the CCD read out in the 11th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_11_REJECT_THR_C","REJTHRC","#ROW == 11","Rejection threshold side C for the CCD read out in the 11th slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_11_REJECT_THR_D","REJTHRD","#ROW == 11","Rejection threshold side D for the CCD read out in the 11th slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_11_CSG_PATTERN","CSGPATT","#ROW == 11","CCD read out in the 11th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_INDEX_12","RDOUTSEQ","#ROW == 12","CCD read out in the 12th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_12_OCB","OCBMODE","#ROW == 12","On-chip binning factor for the CCD read out in the 12th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_12_NODES","READOUT","#ROW == 12","Read-out nodes used fot the CCD read out in the 12th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_12_REJECT_THR_C","REJTHRC","#ROW == 12","Rejection threshold side C for the CCD read out in the 12th slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_12_REJECT_THR_D","REJTHRD","#ROW == 12","Rejection threshold side D for the CCD read out in the 12th slot", Dal::Uint16, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},
  {"CCD_12_CSG_PATTERN","CSGPATT","#ROW == 12","CCD read out in the 12th slot", Dal::Int8, Xmm::RGS2, Xmm::DPP_HOUSEKEEPING_2, false},

  // PN
  {"HBR_0_ACTIVATION_STATUS","HBRPROC","HBRID == 1","Activation status for HBR 0", Dal::Uint16, Xmm::EPN,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_1_ACTIVATION_STATUS","HBRPROC","HBRID == 2","Activation status for HBR 1", Dal::Uint16, Xmm::EPN,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_2_ACTIVATION_STATUS","HBRPROC","HBRID == 3","Activation status for HBR 2", Dal::Uint16, Xmm::EPN,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"HBR_3_ACTIVATION_STATUS","HBRPROC","HBRID == 4","Activation status for HBR 3", Dal::Uint16, Xmm::EPN,Xmm::HBR_CONFIG_HOUSEKEEPING, false},
  {"FILTER_WHEEL_NAME","F1118","F1119 == \"STOPPED\"","Original filter wheel value", Dal::DString, Xmm::EPN, Xmm::MAIN_PERIODIC_HOUSEKEEPING, false},
  {"FILTER_WHEEL_POSITION_POTENTIOMETER","F1122","F1119 == \"STOPPED\"","Hardware filter wheel position", Dal::Real32, Xmm::EPN, Xmm::MAIN_PERIODIC_HOUSEKEEPING, false},
  //  {"FILTER_POTENTIOMETER_RAW","F1122","TRUE","Filter position translated from potentiometer readout", Dal::Real32, Xmm::EPN, Xmm::MAIN_PERIODIC_HOUSEKEEPING, true},
  {"FRAME_TIME_PARAMETER","F1294","TRUE","", Dal::Int8, Xmm::EPN, Xmm::MAIN_PERIODIC_HOUSEKEEPING, true},
  {"CLOCK_RESET_TIME_COARSE","F1030","TRUE","Coarse component of the clock reset time", Dal::Int32, Xmm::EPN, Xmm::MAIN_PERIODIC_HOUSEKEEPING, true},
  {"CLOCK_RESET_TIME_FINE","FU036","TRUE","Fine component of the clock reset time", Dal::Uint16, Xmm::EPN, Xmm::MAIN_PERIODIC_HOUSEKEEPING, true},
  {"CLOCK_WRAP_AROUND","F1052","TRUE","Clock wrap around", Dal::Uint16, Xmm::EPN, Xmm::MAIN_PERIODIC_HOUSEKEEPING, true},
  {"CAMEX_GAIN_CCD1","F1227","TRUE","", Dal::DString, Xmm::EPN, Xmm::MAIN_PERIODIC_HOUSEKEEPING, true},
  {"CAMEX_GAIN_CCD2","F1226","TRUE","", Dal::DString, Xmm::EPN, Xmm::MAIN_PERIODIC_HOUSEKEEPING, true},
  {"CAMEX_GAIN_CCD3","F1225","TRUE","", Dal::DString, Xmm::EPN, Xmm::MAIN_PERIODIC_HOUSEKEEPING, true},
  {"CAMEX_GAIN_CCD4","F1234","TRUE","", Dal::DString, Xmm::EPN, Xmm::MAIN_PERIODIC_HOUSEKEEPING, true},
  {"CAMEX_GAIN_CCD5","F1233","TRUE","", Dal::DString, Xmm::EPN, Xmm::MAIN_PERIODIC_HOUSEKEEPING, true},
  {"CAMEX_GAIN_CCD6","F1232","TRUE","", Dal::DString, Xmm::EPN, Xmm::MAIN_PERIODIC_HOUSEKEEPING, true},
  {"CAMEX_GAIN_CCD7","F1241","TRUE","", Dal::DString, Xmm::EPN, Xmm::MAIN_PERIODIC_HOUSEKEEPING, true},
  {"CAMEX_GAIN_CCD8","F1240","TRUE","", Dal::DString, Xmm::EPN, Xmm::MAIN_PERIODIC_HOUSEKEEPING, true},
  {"CAMEX_GAIN_CCD9","F1239","TRUE","", Dal::DString, Xmm::EPN, Xmm::MAIN_PERIODIC_HOUSEKEEPING, true},
  {"CAMEX_GAIN_CCD10","F1248","TRUE","", Dal::DString, Xmm::EPN, Xmm::MAIN_PERIODIC_HOUSEKEEPING, true},
  {"CAMEX_GAIN_CCD11","F1247","TRUE","", Dal::DString, Xmm::EPN, Xmm::MAIN_PERIODIC_HOUSEKEEPING, true},
  {"CAMEX_GAIN_CCD12","F1246","TRUE","", Dal::DString, Xmm::EPN, Xmm::MAIN_PERIODIC_HOUSEKEEPING, true},
  {"LOWER_THRESHOLD_Q0_CCD0","F1515","TRUE","", Dal::Uint16, Xmm::EPN, Xmm::ADD_PERIODIC_HOUSEKEEPING, true},
  {"LOWER_THRESHOLD_Q0_CCD1","F1516","TRUE","", Dal::Uint16, Xmm::EPN, Xmm::ADD_PERIODIC_HOUSEKEEPING, true},
  {"LOWER_THRESHOLD_Q0_CCD2","F1517","TRUE","", Dal::Uint16, Xmm::EPN, Xmm::ADD_PERIODIC_HOUSEKEEPING, true},
  {"LOWER_THRESHOLD_Q1_CCD0","F1615","TRUE","", Dal::Uint16, Xmm::EPN, Xmm::ADD_PERIODIC_HOUSEKEEPING, true},
  {"LOWER_THRESHOLD_Q1_CCD1","F1616","TRUE","", Dal::Uint16, Xmm::EPN, Xmm::ADD_PERIODIC_HOUSEKEEPING, true},
  {"LOWER_THRESHOLD_Q1_CCD2","F1617","TRUE","", Dal::Uint16, Xmm::EPN, Xmm::ADD_PERIODIC_HOUSEKEEPING, true},
  {"LOWER_THRESHOLD_Q2_CCD0","F1715","TRUE","", Dal::Uint16, Xmm::EPN, Xmm::ADD_PERIODIC_HOUSEKEEPING, true},
  {"LOWER_THRESHOLD_Q2_CCD1","F1716","TRUE","", Dal::Uint16, Xmm::EPN, Xmm::ADD_PERIODIC_HOUSEKEEPING, true},
  {"LOWER_THRESHOLD_Q2_CCD2","F1717","TRUE","", Dal::Uint16, Xmm::EPN, Xmm::ADD_PERIODIC_HOUSEKEEPING, true},
  {"LOWER_THRESHOLD_Q3_CCD0","F1815","TRUE","", Dal::Uint16, Xmm::EPN, Xmm::ADD_PERIODIC_HOUSEKEEPING, true},
  {"LOWER_THRESHOLD_Q3_CCD1","F1816","TRUE","", Dal::Uint16, Xmm::EPN, Xmm::ADD_PERIODIC_HOUSEKEEPING, true},
  {"LOWER_THRESHOLD_Q3_CCD2","F1817","TRUE","", Dal::Uint16, Xmm::EPN, Xmm::ADD_PERIODIC_HOUSEKEEPING, true},
  {"CMCORR_Q0","F1525","TRUE","", Dal::Uint16, Xmm::EPN, Xmm::ADD_PERIODIC_HOUSEKEEPING, true},
  {"CMCORR_Q1","F1625","TRUE","", Dal::Uint16, Xmm::EPN, Xmm::ADD_PERIODIC_HOUSEKEEPING, true},
  {"CMCORR_Q2","F1725","TRUE","", Dal::Uint16, Xmm::EPN, Xmm::ADD_PERIODIC_HOUSEKEEPING, true},
  {"CMCORR_Q3","F1825","TRUE","", Dal::Uint16, Xmm::EPN, Xmm::ADD_PERIODIC_HOUSEKEEPING, true},
  {"QUADRANT_UNDERSAMPLING_Q0","F1534","TRUE","", Dal::Int8, Xmm::EPN, Xmm::ADD_PERIODIC_HOUSEKEEPING, true},
  {"QUADRANT_UNDERSAMPLING_Q1","F1634","TRUE","", Dal::Int8, Xmm::EPN, Xmm::ADD_PERIODIC_HOUSEKEEPING, true},
  {"QUADRANT_UNDERSAMPLING_Q2","F1734","TRUE","", Dal::Int8, Xmm::EPN, Xmm::ADD_PERIODIC_HOUSEKEEPING, true},
  {"QUADRANT_UNDERSAMPLING_Q3","F1834","TRUE","", Dal::Int8, Xmm::EPN, Xmm::ADD_PERIODIC_HOUSEKEEPING, true},

  // OM
  {"EXPOSURE_DURATION","H5440","TRUE","", Dal::Uint16, Xmm::OM, Xmm::PERIODIC_HOUSEKEEPING, true},
  {"FILTER_WHEEL_POSITION","H5265","TRUE","Hardware filter wheel position", Dal::Int16, Xmm::OM, Xmm::PERIODIC_HOUSEKEEPING, true},
  //  {"FILTER_RAW","H5265","TRUE","Filter", Dal::Int16, Xmm::OM, Xmm::PERIODIC_HOUSEKEEPING, true},
};

#endif
