// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//  Giuseppe Vacanti (cosine science & computing bv)
//  January 10, 2003
// 
//   $Id: Instrument.cc,v 1.1 2003/05/06 08:53:03 gvacanti Exp $

#include<Observation.h>
  
OdfIngest::Instrument::Instrument(const XmmInstrument * xi)
  : xmmInstrument_(xi) {
  init_names();
}

OdfIngest::Instrument::Instrument(Xmm::Instrument instrument)
{
  init_names();
  xmmInstrument_ = &xmmPayLoad.instrument(instrument);
}

OdfIngest::Instrument::Instrument(const std::string & nickname) {
  init_names();
  xmmInstrument_ = &xmmPayLoad.instrument(rnicknames_[nickname]);
}

void OdfIngest::Instrument::init_names() {
  nicknames_[Xmm::EMOS1] = "M1";
  nicknames_[Xmm::EMOS2] = "M2";
  nicknames_[Xmm::RGS1] = "R1";
  nicknames_[Xmm::RGS2] = "R2";
  nicknames_[Xmm::EPN] = "PN";
  nicknames_[Xmm::OM] = "OM";
  for(std::map<Xmm::Instrument, std::string>::iterator k = nicknames_.begin();
      k != nicknames_.end(); ++k)
  rnicknames_[(*k).second] = (*k).first;

  configuration_names_[Xmm::EMOS1] = "EPIC MOS";
  configuration_names_[Xmm::EMOS2] = "EPIC MOS";
  configuration_names_[Xmm::RGS1] = "RGS";
  configuration_names_[Xmm::RGS2] = "RGS";
  configuration_names_[Xmm::EPN] = "EPIC PN";
  configuration_names_[Xmm::OM] = "OM";
}  

std::string OdfIngest::Instrument::name() const {
  return Xmm::toString(xmmInstrument_->id());
}

Xmm::Instrument OdfIngest::Instrument::identifier() const {
  return xmmInstrument_->id();
}

std::string OdfIngest::Instrument::nickname() const {
  if(nicknames_.find(identifier()) == nicknames_.end())
    errstr << "Trying to access the name of instrument "
	   << Xmm::toString(xmmInstrument_->id())
	   << " but I could find no match for it."
	   << Sas::error("NoNameAvailable");
  return nicknames_[identifier()];
}

std::string OdfIngest::Instrument::configuration() const {
  if(configuration_names_.find(identifier()) == configuration_names_.end())
    errstr << "Trying to access the name of instrument "
	   << Xmm::toString(xmmInstrument_->id())
	   << " but I could find no match for it."
	   << Sas::error("NoNameAvailable");
  return configuration_names_[identifier()];
}

const OdfIngest::DataModes & OdfIngest::Instrument::science_eng_data_modes() const {
  return xmmInstrument_->scienceEngineeringDataModes();
}

const OdfIngest::DataModes & OdfIngest::Instrument::science_data_modes() const {
  return xmmInstrument_->scienceDataModes();
}

void OdfIngest::Instrument::print(ostream & os) const {
  os << name() << " - " << nickname() << " - " << configuration();
}

std::ostream & OdfIngest::operator<<(std::ostream & os,
			  const Instrument & ins) {
  ins.print(os);
  return os;
}

bool OdfIngest::Instrument::operator==(const Instrument & rhs) const {
  return rhs.identifier() ==  identifier();
}

bool OdfIngest::Instrument::operator!=(const Instrument & rhs) const {
  return (!rhs.identifier() ==  identifier());
}
