// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// XMM Science Analysis System
//
// Giuseppe Vacanti (cosine science & computing) 
// September 2001
//
// $Id: OdfIcd.h,v 1.1 2003/05/06 08:53:04 gvacanti Exp $
//
#ifndef ODFICD_H
#define ODFICD_H

#include <Xmm.h>

#include <string>
#include<Observation.h>

namespace OdfIcd {

  // map instruments to two-letter identifiers (R1, M1 etc)
  std::string instrumentToString(const Xmm::Instrument& i);

  // map data modes to two-letter identifiers (IM, SP etc)
  std::string modeToString(const Xmm::DataMode& d);

  // given the revolution number, the observation identifier
  // (10-characters), the instrument, and the mode, return the
  // corresponding housekeeping file name. Example:
  //    hkname(123, '0123456789', Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_1) =
  //    0123_0123456789_R1X00000D1H.FIT
  // The function has no notion of whether a given data mode is an
  // housekeeping mode.
  std::string hkname(unsigned revolution, const std::string & observation,
		     Xmm::Instrument i, Xmm::DataMode d);

  // as above, but take an integer observation identifier
  std::string hkname(unsigned revolution, unsigned observation,
		     Xmm::Instrument i, Xmm::DataMode d);

  // as above, but take a pointer to an exposure
  std::string hkname(const OdfIngest::Exposure & e, Xmm::DataMode d);


}


#endif
