// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//  Giuseppe Vacanti (cosine science & computing bv)
//  March 11, 2003
// 
//   $Id: DataReaderTest.cc,v 1.1 2003/05/06 08:53:05 gvacanti Exp $

#include<DataReader.h>
#include<cassert>

int main() {

  using namespace SmartDal;

  std::string fname("DataReaderTest.ds");
  {
    DataSetH set = open_set(fname, Create);
    TableH table = set->addTable("table", 100);
    ColumnH column = table->addColumn("Int32", Dal::Int32);
    ColumnDataH cd = column->data();
    int32 * v = cd->data<int32>();
    for(unsigned k = 0; k < table->rows(); ++k)
      v[k] = k;
  }

  DataSetH set = open_set(fname, Read);
  TableH table = set->table("table");
  ColumnH column = table->column("Int32");
  
  DataReader<int32> dri32;
  
  unsigned from = 15;
  unsigned count = 20;
  column->seek(from, count);
  
  const std::vector<int32> & vv = dri32(column);
  
  assert(vv.size() == count);
  for(unsigned k = 0; k < count; ++k)
    assert(vv[k] == static_cast<int32>(k + from));

}
