// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// XMM Science Analysis System
//
// Giuseppe Vacanti (cosine) 
// August 2001
//

#include <Observation.h>
#include <OalServer.h>
#include <iostream>
#include <algorithm>

void Print_Ippv( const OdfIngest::Ippv &i) {
  std::cout << i.name() << " = " << i.value() << std::endl;
}  

void Print_Exposure(const OdfIngest::Exposure &e) {
  std::cout << e.counter() << " " << e.start_time().toString(0)
	    << " " << e.end_time().toString(0)
	    << " " << e.instrument().name() << std::endl;
}

void Process_Exposure(OdfIngest::Exposure &e) {
  std::cout << "Parameters for " << e.counter() << std::endl;
  OdfIngest::Ippvs v = e.ippvs();
  std::for_each(v.begin(), v.end(), Print_Ippv);
  for(OdfIngest::Ippvs::const_iterator k = v.begin(); k != v.end(); ++k)
    assert(e.remove_ippv(k->name()));
  std::cout << "There are now " << e.ippvs().size() << " parameters." << std::endl;
  assert(e.ippvs().size() == 0);  

  OdfIngest::Ippv ip("name", "value");
  assert(e.insert_ippv(ip));
  assert(!e.insert_ippv(ip));
  v = e.ippvs();
  std::for_each(v.begin(), v.end(), Print_Ippv);
  assert(e.ippvs().size() == 1);
}

int main() {
  
  const Odf * odf = oalServer.odf();

  std::vector<OdfIngest::Exposure> expos;

  typedef std::vector<XmmInstrument *>::const_iterator VI;
  for(VI i = xmmPayLoad.instruments().begin();
      i != xmmPayLoad.instruments().end();
      ++i){
    XmmInstrument* ins = *i;
    
    // ERM is not interesting
    if(ins->id() == Xmm::ERM)
      continue;
    
    OdfIngest::Instrument oins(ins);

    const std::vector<Xmm::DataMode> &dm = ins->scienceEngineeringDataModes();
    typedef std::vector<Xmm::DataMode>::const_iterator MI;
    
    for(MI k = dm.begin(); k != dm.end(); ++k)
      for(unsigned l = 1 ; l <= odf->exposures(ins->id(), *k); ++l){
	expos.push_back(
			OdfIngest::Exposure(*(odf->exposure(ins->id(), *k, l)),oins));
      }
  }
  
  std::for_each(expos.begin(), expos.end(), Print_Exposure);  
  std::for_each(expos.begin(), expos.end(), Process_Exposure);  

};
  
