// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//  Giuseppe Vacanti (cosine science & computing bv)
//  August 22, 2003
// 
//   $Id: HkparameterExtractionTest.cc,v 1.3 2003/08/29 14:18:08 gvacanti Exp $

#include<iostream>
#include<cassert>

#include<Hkparameter.h>
#include<Hkparameter_Descriptor.h>
#include<SmartDal>
#include<TimeRows.h>

static Hkparameter_Descriptor id_nper1 = {"HBR_7_PROCESSING_MODE","HBRPROC","HBRID == 8","Processing mode for HBR 7", Dal::Uint16, Xmm::EMOS1,Xmm::HBR_CONFIG_HOUSEKEEPING, false};

static Hkparameter_Descriptor id_nper2 =  {"NUMBER_OF_SLOTS","CCDSNUM","TRUE","Number of readout slots", Dal::Uint16, Xmm::RGS1, Xmm::DPP_HOUSEKEEPING_2, false};

int main() {

  using namespace SmartDal;
  {
    const std::string name = "0153_0129360201_M1X00000HCH.FIT";
    Hkparameter * hkp = Hkparameter::make(id_nper1, 0);
    DataSetH set = open_set(name, Read);
    TableH tab = set->table(0);
    {
      STime start("2000-10-10T01:34:58");
      STime stop("2000-10-10T03:46:38");
      hkp->process(tab,start, stop);
      std::cout << hkp->name() << "=" << hkp->value() << std::endl;
      assert(hkp->value() == "4");
    }
    {
      STime start("2000-10-10T03:58:01");
      STime stop("2000-10-10T07:31:19");
      hkp->process(tab,start, stop);
      std::cout << hkp->name() << "=" << hkp->value() << std::endl;
      assert(hkp->value() == "5");
    }
    
  }

  {
    const std::string name = "0153_0129360201_R1X00000D2H.FIT";
    Hkparameter * hkp = Hkparameter::make(id_nper2, 0);
    DataSetH set = open_set(name, Read);
    TableH tab = set->table(0);
    {
      STime start("2000-10-10T01:30:35");
      STime stop("2000-10-10T08:46:41");
      hkp->process(tab,start, stop);
      std::cout << hkp->name() << "=" << hkp->value() << std::endl;
      assert(hkp->value() == "8");
    }
  }
}
