// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// XMM Science Analysis System
//
// Giuseppe Vacanti (cosine) 
// June 2000
//
#ifndef IPPVEXTRACTOR_H
#define IPPVEXTRACTOR_H

#include <iostream>
#include <vector>
#include <Xmm.h>
#include "Ippv.h"

// The IPPV extractor takes a list if IPPVs for the same instrument,
// reads them from the corresponding ODF datasets, and writes them out.

class IppvExtractor {
 public:
  virtual ~IppvExtractor() {};
  virtual unsigned ippvs() const = 0;
  //AI: Filter identification
  virtual void write(ostream& o,
		     const STime& start,
		     const STime& stop, const std::map<std::string,std::map<string,string>>& epnVals,
			 const string& inst) const = 0;
  virtual void document(ostream& o) const = 0;

  virtual Xmm::Instrument instrument() const = 0;

  // SCR117  
  virtual map<string,string> values(const STime& start,
				     const STime& stop) const = 0;

};

// This is the factory, where we indicate what instrument the IPPVs
// refer to and where on disk are the ODF datasets to be found.

class IppvExtractorServer {
 public:
  IppvExtractorServer();
  ~IppvExtractorServer();
  IppvExtractor * extractor(Xmm::Instrument,
			    const string& directory = ".",
			    const string& label = "");
};

#endif
