// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// XMM Science Analysis System
//
// Giuseppe Vacanti (cosine) 
// September 2000
//
#ifndef IPPVTRANSLATOR_H
#define IPPVTRANSLATOR_H

#include <string>
#include <map>


// Translate IPPVs to strings
template<class T> class IppvTranslator {
 public:
  IppvTranslator();
  virtual ~IppvTranslator();
  virtual const string& look_up(const T& t) const;
  virtual void print(ostream& os) const ;
  virtual bool has_look_up() const;
 protected:
  string _name;
  mutable map<T,string> _map;
};

//

template<class T> class EmosFilterTranslator : public IppvTranslator<T>{
 public:
  EmosFilterTranslator(const string& prefix);
};

template<class T> class EmosGainTranslator : public IppvTranslator<T>{
 public:
  EmosGainTranslator(const string& prefix);
};

template<class T> class EpnFilterWheelTranslator : public IppvTranslator<T>{
 public:
  EpnFilterWheelTranslator();
};

template<class T> class EpnFilterTranslator : public IppvTranslator<T>{
 public:
  EpnFilterTranslator();
  void print(ostream& os) const;
  const string& look_up(const T& t) const;
 private:
  mutable map<pair<real32,real32>, string> _mymap;
};

template<class T> class OmFilterTranslator : public IppvTranslator<T>{
 public:
  OmFilterTranslator();
};

#endif
