// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
// XMM Science Analysis System
//
// Giuseppe Vacanti (cosine) 
// June 2000
//
#ifndef TIMEORDEREDTABLE_H
#define TIMEORDEREDTABLE_H

#include <Dal.h>
#include <STime.h>
#include <string>
#include <vector>
#include <utility>

//
// A DAL table sorted in time ascending order.
//
// lower_bound returns the first row where time(row) >= t, or
// tab->rows() if such row does not exist. It is always row > 0,
// as we want t to be contained in the time range available.
//
// upper_bound returns the last row where time(row) >= t, or
// tab->rows() if such row does not exist. It is always row > 0,
// as we want t to be contained in the time range available.
//

class TimeOrderedTable {
 public:
  TimeOrderedTable(const Table *tab, const string& timename = "TIME");
  ~TimeOrderedTable();
  const Table& table() const;
  unsigned rows() const;
  unsigned validTimes() const;
  unsigned lower_bound(const STime& t) const;
  unsigned upper_bound(const STime& t) const;
  unsigned last_less_than(const STime& t) const;
  unsigned first_less_than(const STime& t) const;
  const STime& time_of_row(const unsigned row) const;
  const STime& first_time() const;
  const STime& last_time() const;
  bool row_has_time(const unsigned row) const;

 private:

  const Table *_tab;
  vector<pair<STime, unsigned> > _stimes;
  ColumnData *_col;

  typedef vector<pair<STime, unsigned> >::const_iterator CI;

};

#endif
